#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_IS_GREATER_EQUAL_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_IS_GREATER_EQUAL_HPP_INCLUDED

#include <boost/simd/operator/include/functions/is_greater_equal.hpp>

#endif
